@@ -106,7 +106,7 @@ class SparseAttention(Attention):
         from deepspeed.ops.sparse_attention import SparseSelfAttention, VariableSparsityConfig
         self.block_size = block_size
 
-        num_random_blocks = default(num_random_blocks, block_size // 4)
+        num_random_blocks = default(num_random_blocks, self.seq_len // block_size // 4)
         global_blocks = uniq(map(lambda t: t // block_size, sparse_attn_global_indices))
 
         self.attn_fn = SparseSelfAttention(
